# valera

[![Codecov](https://img.shields.io/codecov/c/github/tsv1/valera/master.svg?style=flat-square)](https://codecov.io/gh/tsv1/valera)
[![PyPI](https://img.shields.io/pypi/v/valera.svg?style=flat-square)](https://pypi.python.org/pypi/valera/)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/valera?style=flat-square)](https://pypi.python.org/pypi/valera/)
[![Python Version](https://img.shields.io/pypi/pyversions/valera.svg?style=flat-square)](https://pypi.python.org/pypi/valera/)

`valera` is a package designed to validate data based on the [district42](https://github.com/tsv1/district42) schemas. It provides a simple and flexible way for validating data against a defined schema.

This package is part of the [d42 package](https://pypi.org/project/d42/). For a quick-start guide and detailed documentation, please visit the official documentation at [d42.vedro.io/docs/quick-start](https://d42.vedro.io/docs/quick-start)
